{% extends "page.html" %}
{% from "_macros.html" import swan_loader with context %}
{% if announcement_home %}
  {% set announcement = announcement_home %}
{% endif %}

{% block main %}
<div class="container">
  <div class="row">
    {% call swan_loader() %}{% endcall %}
  </div>
</div>
{% endblock %}

{% block script %}
{{ super() }}
<script type="text/javascript">
window.location.replace('{{base_url}}home?changeconfig');
</script>
{% endblock %}
