@import url(icons.css);@font-face{font-family:Roboto;font-style:normal;font-weight:300;src:local('Roboto Light'),url(fonts/Roboto-300.ttf) format('truetype')}@font-face{font-family:Roboto;font-style:normal;font-weight:400;src:local('Roboto'),url(fonts/Roboto-400.ttf) format('truetype')}body{min-height:100vh;display:flex;flex-direction:column}nav.navbar{margin-bottom:3rem!important}nav.navbar ul.navbar-nav{align-items:center}nav+.container,nav+.container-fluid{display:flex;flex-direction:column;min-height:55vh;justify-content:center}footer{margin-top:auto}footer img{max-height:55px}[data-bs-theme=light] h1,[data-bs-theme=light] h2,[data-bs-theme=light] h3,[data-bs-theme=light] h4,[data-bs-theme=light] h5,[data-bs-theme=light] h6{color:#0053a1}[data-bs-theme=light] nav{background-color:#0053a1!important}[data-bs-theme=light] nav li.nav-item{color:#fff}[data-bs-theme=light] nav li.nav-item .swan-nav-link{color:#fff}[data-bs-theme=light] nav li.nav-item .swan-nav-link:hover{background-color:#00407b!important}[data-bs-theme=light] nav #dark-theme-toggle .fa-sun{color:#fff}[data-bs-theme=light] nav #dark-theme-toggle .fa-moon{display:none}[data-bs-theme=dark] h1,[data-bs-theme=dark] h2,[data-bs-theme=dark] h3,[data-bs-theme=dark] h4,[data-bs-theme=dark] h5,[data-bs-theme=dark] h6{color:#60b2ff}[data-bs-theme=dark] nav{background-color:#0f3159!important}[data-bs-theme=dark] nav li.nav-item .swan-nav-link:hover{background-color:#0053a1!important}[data-bs-theme=dark] nav #dark-theme-toggle .fa-sun{display:none}footer .container-fluid{background-color:var(--bs-tertiary-bg)!important}[data-bs-theme=dark] .btn-outline-secondary{color:var(--bs-secondary-color)}[data-bs-theme=dark] .btn-outline-secondary:hover{color:var(--bs-secondary-hover-color)}[data-bs-theme=light] footer img{filter:invert(1)}[data-bs-theme=dark] footer a.link-secondary{color:var(--bs-secondary-color)!important}[data-bs-theme=dark] footer a.link-secondary:hover{color:var(--bs-secondary-hover-color)!important}.version_footer{margin-top:auto}#swan-loader{--loader-size:180px;--ring-width:4px;--ring-color:var(--bs-primary)}#swan-loader .loader-ring{position:relative;width:var(--loader-size);height:var(--loader-size);display:flex;align-items:center;justify-content:center}#swan-loader .loader-ring img{width:60%;height:auto}#swan-loader:not(.loader-error) .loader-ring::before{content:'';position:absolute;inset:0;border-radius:50%;border:var(--ring-width) solid transparent;border-top-color:var(--ring-color);animation:spin 1s linear infinite}#swan-loader .loader-ring::after{content:'';position:absolute;inset:0;border-radius:50%;border:var(--ring-width) solid color-mix(in srgb,var(--ring-color) 15%,transparent)}#swan-loader.loader-error .loader-ring::after{border-color:var(--bs-danger)}@keyframes spin{to{transform:rotate(360deg)}}