{% extends "page.html" %}
{% from "_macros.html" import swan_loader with context %}

{% block login_widget %}
{% endblock %}

{% block main %}

{% block login %}
<main class="container">
  <div class="row">
    {% call swan_loader() %}
      <h4>Logging you in...</h4>
    {% endcall %}
  </div>
</main>
{% endblock login %}

{% endblock %}

{% block script %}
{{super()}}
<script type="text/javascript">
  window.location.replace('{{authenticator_login_url}}');
</script>
{% endblock %}
