{% macro swan_loader(visible=true) %}
<div id="swan-loader" class="{{ 'd-flex' if visible else 'd-none' }} flex-column align-items-center justify-content-center gap-3 py-5">
  <div class="loader-ring">
    <img src="{{ static_url('swan/logos/' + swan_logo_filename) }}" alt="SWAN logo">
  </div>
  {{ caller() }}
</div>
{% endmacro %}
